@@ -256,3 +256,79 @@ USER_INDEX_MAP = textwrap.dedent(
     }
     """
 )
+
+FEATURE_INDEX_MAP = textwrap.dedent(
+    """
+    {
+    "settings": {
+      "analysis": {
+        "normalizer": {
+          "lowercase_normalizer": {
+            "type": "custom",
+            "filter": ["lowercase"]
+          }
+        }
+      }
+    },
+    "mappings":{
+        "feature":{
+          "properties": {
+            "feature_group": {
+              "type":"text",
+              "fields": {
+                "raw": {
+                  "type": "keyword",
+                  "normalizer": "lowercase_normalizer"
+                }
+              }
+            },
+            "feature_name": {
+              "type":"text",
+              "fields": {
+                "raw": {
+                  "type": "keyword",
+                  "normalizer": "lowercase_normalizer"
+                }
+              }
+            },
+            "version": {
+              "type": "keyword",
+              "normalizer": "lowercase_normalizer"
+            },
+            "total_usage":{
+              "type": "long"
+            },
+            "status": {
+              "type": "keyword"
+            },
+            "entity": {
+              "type": "keyword"
+            },
+            "description": {
+              "type": "text"
+            },
+            "availability": {
+              "type": "text",
+              "analyzer": "simple",
+              "fields": {
+                "raw": {
+                  "type": "keyword"
+                }
+              }
+            },
+            "badges": {
+              "type": "keyword"
+            },
+            "tags": {
+              "type": "keyword"
+            },
+            "last_updated_timestamp": {
+              "type": "date",
+              "format": "epoch_second"
+            }
+          }
+        }
+      }
+    }
+    """
+)
