@@ -125,6 +125,48 @@ class ProgrammaticDescriptionSchema(AttrsSchema):
         register_as_scheme = True
 
 
+@attr.s(auto_attribs=True, kw_only=True)
+class TableSummary:
+    database: str = attr.ib()
+    cluster: str = attr.ib()
+    schema: str = attr.ib()
+    name: str = attr.ib()
+    description: Optional[str] = attr.ib(default=None)
+    schema_description: Optional[str] = attr.ib(default=None)
+
+
+class TableSummarySchema(AttrsSchema):
+    class Meta:
+        target = TableSummary
+        register_as_scheme = True
+
+
+@attr.s(auto_attribs=True, kw_only=True)
+class SqlJoin:
+    column: str
+    joined_on_table: TableSummary
+    joined_on_column: str
+    join_type: str
+    join_sql: str
+
+
+class SqlJoinSchema(AttrsSchema):
+    class Meta:
+        target = SqlJoin
+        register_as_scheme = True
+
+
+@attr.s(auto_attribs=True, kw_only=True)
+class SqlWnere:
+    where_clause: str
+
+
+class SqlWhereSchema(AttrsSchema):
+    class Meta:
+        target = SqlWnere
+        register_as_scheme = True
+
+
 @attr.s(auto_attribs=True, kw_only=True)
 class Table:
     database: str
@@ -145,25 +187,11 @@ class Table:
     source: Optional[Source] = None
     is_view: Optional[bool] = attr.ib(default=None, converter=default_if_none)
     programmatic_descriptions: List[ProgrammaticDescription] = []
+    common_joins: Optional[List[SqlJoin]] = None
+    common_filters: Optional[List[SqlWnere]] = None
 
 
 class TableSchema(AttrsSchema):
     class Meta:
         target = Table
         register_as_scheme = True
-
-
-@attr.s(auto_attribs=True, kw_only=True)
-class TableSummary:
-    database: str = attr.ib()
-    cluster: str = attr.ib()
-    schema: str = attr.ib()
-    name: str = attr.ib()
-    description: Optional[str] = attr.ib(default=None)
-    schema_description: Optional[str] = attr.ib(default=None)
-
-
-class TableSummarySchema(AttrsSchema):
-    class Meta:
-        target = TableSummary
-        register_as_scheme = True
